Introduction
============

.. note::

   This package is in beta. The API may change in future versions. Please use the `GitHub issue tracker <https://github.com/jeffgortmaker/pyblp/issues>`_ to report bugs or to request features.

.. include:: ../README.rst
   :start-after: docs-start
